@@ -4,9 +4,22 @@ setMethod("summary",
   {
     Rngsumar <- summary(exp(object@LogR))
     dimnames(Rngsumar)[[2]] <- paste(object@VarNames,".Range",sep="")
-    res <- list(MidPsumar=summary(object@MidP),Rngsumar=Rngsumar,LogRsumar=summary(object@LogR))
-    class(res) <- "summaryIData"
-    res
+
+#cat("summary.IData 1 -- got here\n")
+#cat("str(object@MidP) =\n") ; print(str(object@MidP))
+#cat("str(summary(object@MidP)) =\n") ; print(str(summary(object@MidP)))
+#cat("str(Rngsumar =\n") ; print(str(Rngsumar))
+#cat("str(object@LogR) =\n") ; print(str(object@LogR))
+#cat("str(summary(object@LogR)) =\n") ; print(str(summary(object@LogR)))
+
+#cat("methods(print) =\n") ; print(methods(print))
+#cat("getS3method(print,summaryIData,optional = TRUE) =\n") ; getS3method("print","summaryIData",optional = TRUE)
+
+#cat("summary.IData 2 -- got here\n")
+
+
+#    new("summaryIData",MidPsumar=summary(object@MidP),Rngsumar=Rngsumar,LogRsumar=summary(object@LogR))
+    show(new("summaryIData",MidPsumar=summary(object@MidP),Rngsumar=Rngsumar,LogRsumar=summary(object@LogR)))
   }
 )
 
@@ -37,13 +50,14 @@ setMethod("show",
       cat(rep(" ",nspaces),object@VarNames[j],sep="" )
     }  
     cat("\n") 
-    apply(cbind(format(object@ObsNames,width=lobsname),LB,UB),1,printrow,NIVar=object@NIVar)
+    apply(cbind.data.frame(format(object@ObsNames,width=lobsname),LB,UB),1,printrow,NIVar=object@NIVar)
     invisible(object)
   }
 )
 
 setMethod("nrow",signature(x = "IData"),function(x) x@NObs)
 setMethod("ncol",signature(x = "IData"),function(x) x@NIVar)
+setMethod("dim",signature(x = "IData"),function(x) c(nrow(x),ncol(x)))
 setMethod("rownames",signature(x = "IData"),function(x) x@ObsNames)
 setMethod("colnames",signature(x = "IData"),function(x) x@VarNames)
 setMethod("names",signature(x = "IData"),function(x) x@VarNames)
@@ -66,9 +80,11 @@ setMethod("head",
   {
     
     if (n>0) {
-      x[1:n,] 
+#      x[1:n,] 
+      x[1:n,1:x@NIVar] 
     } else {
-      x[-1:n,]
+#      x[-1:n,]
+      x[-1:n,1:x@NIVar]
     }
   }
 )
@@ -78,9 +94,11 @@ setMethod("tail",
   function (x,n=min(nrow(x),6L)) 
   {
     if (n>0) {
-      x[(x@NObs-n+1):x@NObs,] 
+#      x[(x@NObs-n+1):x@NObs,] 
+      x[(x@NObs-n+1):x@NObs,1:x@NIVar] 
     } else {
-      x[(-x@NObs-n-1):-x@NObs,]
+#      x[(-x@NObs-n-1):-x@NObs,]
+      x[(-x@NObs-n-1):-x@NObs,1:x@NIVar]
     }
   }
 )
@@ -146,7 +164,6 @@ setMethod("plot",
   {
     if (x@NIVar > 1) {
       if (x@NIVar==2) {
-#        plot(x[,1],x[,2],...)
         plot.default(x[,1],x[,2],...)
         return()
       } else {
@@ -161,16 +178,22 @@ setMethod("plot",
       dotarguments$main <- x@VarNames
     }
     if (is.null(dotarguments$ylab)) {
-      dotarguments$ylab <- x@VarNames
+#      dotarguments$ylab <- x@VarNames
+      if (layout=="vertical") dotarguments$ylab <- x@VarNames
+      else dotarguments$ylab <- "Case numbers"
     }
     if (is.null(dotarguments$xlab)) {
-        dotarguments$xlab <- "Case numbers"
+#        dotarguments$xlab <- "Case numbers"
+        if (layout=="vertical") dotarguments$xlab <- "Case numbers"
+        else dotarguments$xlab <- x@VarNames
     }
 
     HlfRngy <- exp(x@LogR[,1])/2
     Lby <- x@MidP[,1] - HlfRngy
     Uby <- x@MidP[,1] + HlfRngy
     xcord <- 1:x@NObs
+    if (!append) xcord <- 1:x@NObs
+    else xcord <- 1:x@NObs + runif(x@NObs,-0.5,0.5)
 
     if (is.null(dotarguments$ylim) && layout=="vertical") {
       minvy <- min(Lby)
@@ -190,13 +213,11 @@ setMethod("plot",
     }
     if (layout=="vertical") {
       if (!append) {
-#        do.call("plot",c(list(x=casen,y=rep(0.,length(casen)),type="n"),dotarguments))
-        do.call("plot,default",c(list(x=casen,y=rep(0.,length(casen)),type="n"),dotarguments))
+        do.call("plot.default",c(list(x=casen,y=rep(0.,length(casen)),type="n"),dotarguments))
       }
       do.call("segments",c(list(x0=xcord,y0=Lby,x1=xcord,y1=Uby),dotarguments))
     } else  {
       if (!append) {
-#        do.call("plot",c(list(x=rep(0.,length(casen)),y=casen,type="n"),dotarguments))
         do.call("plot.default",c(list(x=rep(0.,length(casen)),y=casen,type="n"),dotarguments))
       }
       do.call("segments",c(list(y0=xcord,x0=Lby,y1=xcord,x1=Uby),dotarguments))
@@ -204,18 +225,37 @@ setMethod("plot",
   }
 )
 
-print.summaryIData <- function(x,...) 
-{
-  cat("Mid-Points summary:\n") ; print(x$MidPsumar)
-  cat("Ranges summary:\n") ; print(x$Rngsumar)
-  cat("Log-Ranges summary:\n") ; print(x$LogRsumar)
-  invisible(x)
-}
+setMethod("show",
+  signature(object = "summaryIData"),
+  function(object)
+  {
+
+#cat("show(summaryIData) -- got here")
+#cat("str(object@MidPsumar) =",str(object@MidPsumar),"\n") 
+#cat("str(object@MidPsumar) =",str(object@Rngsumar),"\n") 
+#cat("str(object@MidPsumar) =",str(object@LogRsumar),"\n") 
+
+    cat("Mid-Points summary:\n") ; print(object@MidPsumar)
+    cat("Ranges summary:\n") ; print(object@Rngsumar)
+    cat("Log-Ranges summary:\n") ; print(object@LogRsumar)
+    invisible(object)
+  }
+)
+
+#print.summaryIData <- function(x,...) 
+#{
+#  cat("Mid-Points summary:\n") ; print(x$MidPsumar)
+#  cat("Ranges summary:\n") ; print(x$Rngsumar)
+#  cat("Log-Ranges summary:\n") ; print(x$LogRsumar)
+#  invisible(x)
+#}
+
+setMethod("print", signature(x="summaryIData"), function(x,...) invisible(x) )
 
 IData <- function(Data,
   Seq=c("LbUb_VarbyVar","MidPLogR_VarbyVar","AllLb_AllUb","AllMidP_AllLogR"),VarNames=NULL,ObsNames=row.names(Data))
 {
-  if (!(is.data.frame(Data))) stop("First argument of IData must be a data frame\n")
+  if ( !is.data.frame(Data) && !is.matrix(Data) ) stop("First argument of IData must be a data frame or a matrix\n")
   p <- ncol(Data)  # Total number of Interval variable bounds
   q <- p/2	 # Number of Interval variables
   if (floor(q) != q) stop("Number of columns of Data ( =",p,") must be an even number\n")
@@ -245,100 +285,127 @@ IData <- function(Data,
 
 # Indexing and assignement
 
-"[.IData" <- function(x,rowi=1:x@NObs,coli=1:x@NIVar,...)
-{
-  if (class(rowi)[1]=="character") rowi <- sapply(rowi,function(ri) which(ri==x@ObsNames))
-  if (class(coli)[1]=="character") coli <- sapply(coli,function(ci) which(ci==x@VarNames))
-  IData(cbind(x@MidP[rowi,coli,drop=FALSE],x@LogR[rowi,coli,drop=FALSE]),
-    Seq="AllMidP_AllLogR",VarNames=x@VarNames[coli],ObsNames=x@ObsNames[rowi])
-}
+setMethod("[",
+  signature(x='IData',i='ANY',j='ANY'),
+  function(x,i,j,...,drop=TRUE)
+  {
+    if (missing(i)) i <- 1:nrow(x)  
+    if (missing(j)) j <- 1:ncol(x)  
+    if (class(i)[1]=="character") i <- sapply(i,function(ri) which(ri==x@ObsNames))
+    if (class(j)[1]=="character") j <- sapply(j,function(ci) which(ci==x@VarNames))
+    IData(cbind.data.frame(x@MidP[i,j,drop=FALSE],x@LogR[i,j,drop=FALSE]),
+      Seq="AllMidP_AllLogR",VarNames=x@VarNames[j],ObsNames=x@ObsNames[i])
+  }
+)
 
-"[<-.IData" <- function(x,rowi=1:x@NObs,coli=1:x@NIVar,value)
-{
-  if (!is(value,"IData")) stop("Argument value is not an IData object\n")
-  if (class(rowi)[1]=="character") rowi <- sapply(rowi,function(ri) which(ri==x@ObsNames))
-  if (class(coli)[1]=="character") coli <- sapply(coli,function(ci) which(ci==x@VarNames))
-  x@MidP[rowi,coli] <- value@MidP
-  x@LogR[rowi,coli] <- value@LogR
-  x
-}
+setMethod("[<-",
+  signature(x='IData',i='ANY',j='ANY'),
+  function(x,i,j,value)
+  {
+    if (!is(value,"IData")) stop("Argument value is not an IData object\n")
+    if (missing(i)) i <- 1:nrow(x)  
+    if (missing(j)) j <- 1:ncol(x)  
+    if (class(i)[1]=="character") i <- sapply(i,function(ri) which(ri==x@ObsNames))
+    if (class(j)[1]=="character") j <- sapply(j,function(ci) which(ci==x@VarNames))
+    x@MidP[i,j] <- value@MidP
+    x@LogR[i,j] <- value@LogR
+    x
+  }
+)
 
 # Comparison
 
-"==.IData" <- function(x,y)
-{
-  CompIvalue <- function(Ival) Ival[1,1] == Ival[1,2] && Ival[2,1] == Ival[2,2]
+setMethod("==",
+  signature(e1 = "IData",e2 = "IData"),
+  function(e1,e2)
+  {
+    CompIvalue <- function(Ival) Ival[1,1] == Ival[1,2] && Ival[2,1] == Ival[2,2]
 
-  if (!is(y,"IData")) 
-    stop("Trying to compare an IData object with an object of a diferent type\n")
-  if ( x@NObs != y@NObs || x@NIVar != y@NIVar )
-    stop("== only defined for equally-sized IData objects\n")
-  TmpArray <- array(dim=c(x@NObs,x@NIVar,2,2))
-  for (j in 1:x@NIVar)  {
-    TmpArray[,j,,1] <- cbind(x@MidP[,j],x@LogR[,j])
-    TmpArray[,j,,2] <- cbind(y@MidP[,j],y@LogR[,j])
+    if (!is(e2,"IData")) 
+      stop("Trying to compare an IData object with an object of a diferent type\n")
+    if ( e1@NObs != e2@NObs || e1@NIVar != e2@NIVar )
+      stop("== only defined for equally-sized IData objects\n")
+    TmpArray <- array(dim=c(e1@NObs,e1@NIVar,2,2))
+    for (j in 1:e1@NIVar)  {
+#      TmpArray[,j,,1] <- cbind(e1@MidP[,j],e1@LogR[,j])
+#      TmpArray[,j,,2] <- cbind(e2@MidP[,j],e2@LogR[,j])
+      TmpArray[,j,,1] <- cbind.data.frame(e1@MidP[,j],e1@LogR[,j])
+      TmpArray[,j,,2] <- cbind.data.frame(e2@MidP[,j],e2@LogR[,j])
+    }
+
+    apply(TmpArray,c(1,2),CompIvalue)
   }
-  apply(TmpArray,c(1,2),CompIvalue)
-}
+)
 
-"!=.IData" <- function(x,y)  
-{
-  if (!is(y,"IData"))
-    stop("Trying to compare an IData object with an object of a diferent type\n")
-  if ( x@NObs != y@NObs || x@NIVar != y@NIVar )
-    stop("!= only defined for equally-sized IData objects\n")
-  !(x==y)
-}
-
-rbind.IData <- function(x, y, ...)
-{
-  if (class(x)[1]!="IData") stop("Argument x is not an object of class IData\n")
-  if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
-  if (x@NIVar != y@NIVar) stop("Arguments x and y have a different number of interval-valued variables\n")
-  dataDF <- rbind(cbind(x@MidP,x@LogR),cbind(y@MidP,y@LogR))
-  if (x@NIVar==1) {
-    ONames <- c(x@ObsNames,y@ObsNames)
-  } else {
-    ONames <- rownames(dataDF)
+setMethod("!=",
+  signature(e1 = "IData",e2 = "IData"),
+  function(e1,e2)  
+  {
+    if (!is(e2,"IData"))
+      stop("Trying to compare an IData object with an object of a diferent type\n")
+    if ( e1@NObs != e2@NObs || e1@NIVar != e2@NIVar )
+      stop("!= only defined for equally-sized IData objects\n")
+    !(e1==e2)
   }
-  par <- match.call()
-  lpar <- length(par)
-  if (lpar>4) for (i in 3:(lpar-2))  {
-    newIDtObj <- eval(par[[i]])
-    if (i==3) auxtxt <- "rd " else auxtxt <- "-th "
-    if (class(newIDtObj)[1]!="IData") stop("The ",i,auxtxt,"argument is not an object of class IData\n")
-    if (x@NIVar != newIDtObj@NIVar) stop("First and ",i,auxtxt,"argument have a different number of interval-valued variables\n")
-    dataDF <- rbind(dataDF,cbind(newIDtObj@MidP,newIDtObj@LogR))
+)
+
+setMethod(rbind,
+  signature(x = "IData"),
+  function(x, y, ...)
+  {
+    if (class(x)[1]!="IData") stop("Argument x is not an object of class IData\n")
+    if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
+    if (x@NIVar != y@NIVar) stop("Arguments x and y have a different number of interval-valued variables\n")
+#    dataDF <- rbind(cbind(x@MidP,x@LogR),cbind(y@MidP,y@LogR))
+    dataDF <- rbind.data.frame(cbind.data.frame(x@MidP,x@LogR),cbind.data.frame(y@MidP,y@LogR))
     if (x@NIVar==1) {
-      ONames <- c(ONames,newIDtObj@ObsNames)
+      ONames <- c(x@ObsNames,y@ObsNames)
     } else {
       ONames <- rownames(dataDF)
     }
-  }  
-  IData(dataDF,Seq="AllMidP_AllLogR",ObsNames=ONames,VarNames=x@VarNames)
-}
-
-cbind.IData <- function(x, y, ...)
-{
-  if (class(x)[1]!="IData") stop("Argument x is not an object of class IData\n")
-  if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
-  if (x@NObs != y@NObs) stop("Arguments x and y have a different number of rows\n")
-  dataDF <- cbind(x@MidP,y@MidP,x@LogR,y@LogR)
-  if (x@NIVar==1 && y@NIVar==1) rownames(dataDF) <- x@ObsNames
-  VNames <- c(x@VarNames,y@VarNames)
-  par <- match.call()
-  lpar <- length(par)
-  curnIvar <- x@NIVar + y@NIVar
-  if (lpar>4) for (i in 3:(lpar-2))  {
-    newIDtObj <- eval(par[[i]])
-    if (i==3) auxtxt <- "rd " else auxtxt <- "-th "
-    if (class(newIDtObj)[1]!="IData") stop("The ",i,auxtxt,"argument is not an object of class IData\n")
-    if (x@NObs != newIDtObj@NObs) stop("First and ",i,auxtxt,"argument have a different number of rows\n")
-    dataDF <- cbind(dataDF[,1:curnIvar],newIDtObj@MidP,dataDF[,(curnIvar+1):(2*curnIvar)],newIDtObj@LogR)
-    VNames <- c(VNames,newIDtObj@VarNames)
-    curnIvar <- curnIvar + newIDtObj@NIVar
-  }  
-  IData(dataDF,Seq="AllMidP_AllLogR",VarNames=VNames)
-}
-
+    par <- match.call()
+    lpar <- length(par)
+    if (lpar>4) for (i in 3:(lpar-2))  {
+      newIDtObj <- eval(par[[i]])
+      if (i==3) auxtxt <- "rd " else auxtxt <- "-th "
+      if (class(newIDtObj)[1]!="IData") stop("The ",i,auxtxt,"argument is not an object of class IData\n")
+      if (x@NIVar != newIDtObj@NIVar) stop("First and ",i,auxtxt,"argument have a different number of interval-valued variables\n")
+#      dataDF <- rbind(dataDF,cbind(newIDtObj@MidP,newIDtObj@LogR))
+      dataDF <- rbind.data.frame(dataDF,cbind.data.frame(newIDtObj@MidP,newIDtObj@LogR))
+      if (x@NIVar==1) {
+        ONames <- c(ONames,newIDtObj@ObsNames)
+      } else {
+        ONames <- rownames(dataDF)
+      }
+    }  
+    IData(dataDF,Seq="AllMidP_AllLogR",ObsNames=ONames,VarNames=x@VarNames)
+  }
+)
 
+setMethod(cbind,
+  signature(x = "IData"),
+  function(x, y, ...)
+  {
+    if (class(x)[1]!="IData") stop("Argument x is not an object of class IData\n")
+    if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
+    if (x@NObs != y@NObs) stop("Arguments x and y have a different number of rows\n")
+#    dataDF <- cbind(x@MidP,y@MidP,x@LogR,y@LogR)
+    dataDF <- cbind.data.frame(x@MidP,y@MidP,x@LogR,y@LogR)
+    if (x@NIVar==1 && y@NIVar==1) rownames(dataDF) <- x@ObsNames
+    VNames <- c(x@VarNames,y@VarNames)
+    par <- match.call()
+    lpar <- length(par)
+    curnIvar <- x@NIVar + y@NIVar
+    if (lpar>4) for (i in 3:(lpar-2))  {
+      newIDtObj <- eval(par[[i]])
+      if (i==3) auxtxt <- "rd " else auxtxt <- "-th "
+      if (class(newIDtObj)[1]!="IData") stop("The ",i,auxtxt,"argument is not an object of class IData\n")
+      if (x@NObs != newIDtObj@NObs) stop("First and ",i,auxtxt,"argument have a different number of rows\n")
+#      dataDF <- cbind(dataDF[,1:curnIvar],newIDtObj@MidP,dataDF[,(curnIvar+1):(2*curnIvar)],newIDtObj@LogR)
+      dataDF <- cbind.data.frame(dataDF[,1:curnIvar],newIDtObj@MidP,dataDF[,(curnIvar+1):(2*curnIvar)],newIDtObj@LogR)
+      VNames <- c(VNames,newIDtObj@VarNames)
+      curnIvar <- curnIvar + newIDtObj@NIVar
+    }  
+    IData(dataDF,Seq="AllMidP_AllLogR",VarNames=VNames)
+  }
+)
